@@ -26,13 +26,15 @@ class XMLCompiler:
     }
     
     def __init__(self, external_components_dir=None):
+        # 初始化组件缓存
+        ComponentMixin._load_all_components(external_components_dir)
         self.processors = [
             StyleProcessor(),
             DirectiveProcessor(), 
             TableProcessor(),
             ParagraphProcessor(),
             PagerProcessor(),
-            ComponentMixin(external_components_dir)
+            ComponentMixin
         ]
         self.env = Environment(
             loader=XMLTemplateLoader(""),
