@@ -104,7 +104,7 @@ class ParagraphProcessor(BaseProcessor):
      
             def process_span(match):
                 style_str = match.group(1) or ''
-                content = match.group(2).strip()
+                content = match.group(2)
                 styles = cls._parse_style_str(style_str)
                 underline, font_size, font_weight, color, spacing = cls.retrieve(styles, ['underline', 'font-size', 'font-weight', 'color', 'spacing'])
                 r_props_str_ = r_props_str
