@@ -149,12 +149,6 @@ class TableProcessor(BaseProcessor):
             margin_left = styles.get('margin-left', '0')
             tbl_props_str += f'<w:tblInd w:w="{margin_left}" w:type="dxa"/>'
             
-            # 处理表格宽度
-            if width_str:
-                tbl_props_str += f'<w:tblW w:w="{width_str}" w:type="dxa"/>'
-            else:
-                tbl_props_str += '<w:tblW w:type="auto" w:w="0"/>'
-            
             # 添加单元格边距设置
             padding_top = styles.get('padding-top', '0')
             padding_bottom = styles.get('padding-bottom', '0')
@@ -170,13 +164,15 @@ class TableProcessor(BaseProcessor):
                 </w:tblCellMar>
             '''
             
-            # 处理列宽设置
+            # 处理列宽设置并计算网格宽度总和
             tbl_grid_str = ''
+            grid_total_width = None
             if span_str and width_str:
                 # span属性优先，根据span和width自动计算grid
                 calculated_grid = cls.calculate_grid_from_span(width_str, span_str)
                 if calculated_grid:
                     col_widths = calculated_grid.split('/')
+                    grid_total_width = sum(int(w) for w in col_widths)
                     tbl_grid_str = '<w:tblGrid>'
                     for width in col_widths:
                         tbl_grid_str += f'<w:gridCol w:w="{width}"/>'
@@ -184,11 +180,21 @@ class TableProcessor(BaseProcessor):
             elif grid_str:
                 # 如果没有span属性，使用grid属性
                 col_widths = grid_str.split('/')
+                grid_total_width = sum(int(w) for w in col_widths)
                 tbl_grid_str = '<w:tblGrid>'
                 for width in col_widths:
                     tbl_grid_str += f'<w:gridCol w:w="{width}"/>'
                 tbl_grid_str += '</w:tblGrid>'
             
+            # 处理表格宽度
+            if width_str:
+                tbl_props_str += f'<w:tblW w:w="{width_str}" w:type="dxa"/>'
+            elif grid_total_width is not None:
+                # 如果没有width但有grid，使用grid的总和
+                tbl_props_str += f'<w:tblW w:w="{grid_total_width}" w:type="dxa"/>'
+            else:
+                tbl_props_str += '<w:tblW w:type="auto" w:w="0"/>'
+            
             return f'''<w:tbl><w:tblPr>{tbl_props_str}</w:tblPr>{tbl_grid_str}{content}</w:tbl>'''
             
         return cls._process_tag(xml, cls.XL_TABLE_PATTERN, process_table)
@@ -362,6 +368,10 @@ class TableProcessor(BaseProcessor):
             if style:
                 content = cls._merge_tc_style_to_content(content, style)
 
+            # 如果没有显式设置width，尝试从父级表格的grid计算
+            if not width:
+                width = cls._calculate_cell_width_from_grid(xml, match.start())
+
             tc_props_str = ''
             # 添加各种单元格属性
             tc_props_str += f'<w:tcW w:type="dxa" w:w="{width}"/>' if width else ''
@@ -377,7 +387,7 @@ class TableProcessor(BaseProcessor):
             tc_props_str += tc_border_str
             return f'<w:tc>\n                    <w:tcPr>{tc_props_str}</w:tcPr>{content}</w:tc>'
         
-        data = cls._process_tag(xml, cls.XL_TC_PATTERN, process_tc)
+        data = cls._process_tag(xml, cls.XL_TC_PATTERN, process_tc, flags=re.VERBOSE | re.DOTALL)
         return data
     
     @classmethod
@@ -677,6 +687,106 @@ class TableProcessor(BaseProcessor):
         
         return '/'.join(col_widths)
 
+    @classmethod
+    def _calculate_cell_width_from_grid(cls, xml: str, tc_position: int) -> str:
+        """根据父级表格的grid属性计算单元格宽度"""
+        # 从当前位置向前查找最近的w:tbl标签
+        table_start = xml.rfind('<w:tbl', 0, tc_position)
+        if table_start == -1:
+            return None
+        
+        # 找到tblGrid标签
+        tblgrid_start = xml.find('<w:tblGrid>', table_start, tc_position)
+        if tblgrid_start == -1:
+            return None
+        
+        tblgrid_end = xml.find('</w:tblGrid>', tblgrid_start)
+        if tblgrid_end == -1:
+            return None
+        
+        tblgrid_content = xml[tblgrid_start:tblgrid_end]
+        
+        # 提取所有gridCol的宽度
+        grid_widths = []
+        for gridcol_match in re.finditer(r'<w:gridCol\s+w:w="([^"]+)"/>', tblgrid_content):
+            grid_widths.append(int(gridcol_match.group(1)))
+        
+        if not grid_widths:
+            return None
+        
+        # 找到当前单元格所在的w:tr
+        tr_start = xml.rfind('<w:tr', 0, tc_position)
+        if tr_start == -1:
+            return None
+        
+        tr_end = xml.find('</w:tr>', tr_start)
+        if tr_end == -1:
+            return None
+        
+        tr_content = xml[tr_start:tr_end]
+        
+        # 去掉w:trPr部分，只保留单元格内容
+        trpr_end = tr_content.find('</w:trPr>')
+        trpr_offset = 0
+        if trpr_end != -1:
+            trpr_offset = trpr_end + len('</w:trPr>')
+        
+        # Calculate position within tr (accounting for trPr)
+        tc_position_in_tr = tc_position - tr_start - trpr_offset
+        
+        # Extract xl-tc content (after trPr)
+        tc_content_start = trpr_offset
+        tc_content = tr_content[tc_content_start:]
+        
+        # 计算当前单元格在行中的位置 - 在转换后的XML中查找xl-tc标签（因为tc还没完全被转换）
+        # 使用更简单的模式匹配xl-tc开始标签，避免嵌套内容的问题
+        XL_TC_START_PATTERN = r'<xl-tc([^>]*)>'
+        tc_matches = list(re.finditer(XL_TC_START_PATTERN, tc_content))
+        current_tc_index = -1
+        for i, tc_match in enumerate(tc_matches):
+            tc_start_pos = tc_match.start()
+            # Find the start position of the next xl-tc tag (or end of content)
+            if i + 1 < len(tc_matches):
+                next_tc_start = tc_matches[i + 1].start()
+            else:
+                # Last cell, find the </xl-tc> tag
+                tc_end_pos = tc_content.find('</xl-tc>', tc_match.end())
+                if tc_end_pos == -1:
+                    continue
+                next_tc_start = tc_end_pos + len('</xl-tc>')
+            
+            # Check if tc_position_in_tr falls within this cell's start tag
+            # We only match based on the start position to avoid end tag edge cases
+            if tc_start_pos <= tc_position_in_tr < next_tc_start:
+                current_tc_index = i
+                break
+        
+        if current_tc_index == -1:
+            return None
+        
+        # 计算当前单元格应该使用的grid列
+        # 从xl-tc属性中提取span值
+        current_col = 0
+        for i in range(current_tc_index):
+            tc_attrs = tc_matches[i].group(1)
+            span = cls._extract_attr(tc_attrs, 'span')
+            if span:
+                current_col += int(span)
+            else:
+                current_col += 1
+        
+        # 获取当前单元格的span值
+        current_tc_attrs = tc_matches[current_tc_index].group(1)
+        span = cls._extract_attr(current_tc_attrs, 'span')
+        span_count = int(span) if span else 1
+        
+        # 计算宽度：从current_col开始，取span_count个grid宽度
+        if current_col + span_count > len(grid_widths):
+            return None
+        
+        width = sum(grid_widths[current_col:current_col + span_count])
+        return str(width)
+
     @classmethod
     def _extract_attr(cls, attrs: str, attr_name: str) -> str:
         """从属性字符串中提取指定属性的值"""
