@@ -17,30 +17,6 @@ class Document(Sheet):
             return []
         return [f for f in Path(self.elements_folder).rglob('*.xml')]    
 
-    def _build_element_template(self):
-        """构建组件模板字符串
-        
-        Args:
-            element_files: 组件文件列表
-            
-        Returns:
-            str: 组合后的模板字符串
-        """
-        element_files = self._get_element_files()
-
-        template_parts = ['($ for item in data $)']
-        
-        for index, filepath in enumerate(element_files):
-            element_type = filepath.stem
-            element_content = self._read_element_file(filepath)
-            condition = 'if' if index == 0 else 'elif'
-            template_parts.append(
-                f"($ {condition} item['element']=='{element_type}' $){element_content}"
-            )
-
-        template_parts.extend(['($ endif $)', '($ endfor $)'])
-        return ''.join(template_parts)
-    
     def _read_element_file(self, filepath):
         """读取组件文件内容
         
@@ -64,12 +40,13 @@ class Document(Sheet):
                 element_content = self._read_element_file(filepath)
                 if item.get('element') == element_type:
                     element_data = item.get('data')
-                    element_content = ComponentMixin(self.components_folder).process_components(element_content)
+                    element_content = ComponentMixin.process_components(element_content)
                     element_content = XMLCompiler.convert_syntax(element_content)
                     element_content = self.render_template(element_content, element_data, is_compile=False)
                     template_xml += element_content
         document_xml = self.render_xml('document', dict(document=template_xml)).decode()
         document_xml = self.render_template(document_xml, {})
+        document_xml = self._process_image_data(document_xml, 'document.xml')
         self['word/document.xml'] = document_xml.encode('utf-8')
 
 
