@@ -21,35 +21,33 @@ class ComponentMixin:
         </\1>                                # 结束标签
     '''
     
-    def __init__(self, external_components_dir=None):
-        # 组件缓存，避免重复读取文件
-        self._component_cache = {}
-        # 获取内置components目录路径
-        self._builtin_components_dir = os.path.join(
+    # 组件缓存，避免重复读取文件（类变量）
+    _component_cache = {}
+    
+    @classmethod
+    def _load_all_components(cls, external_components_dir=None):
+        """一次性加载所有组件到缓存中"""
+        cls._load_builtin_components()
+        cls._load_external_components(external_components_dir=external_components_dir)
+    
+    @classmethod
+    def _load_builtin_components(cls):
+        """加载内置组件目录中的所有组件"""
+        builtin_components_dir = os.path.join(
             os.path.dirname(os.path.dirname(__file__)),
             'components'
         )
-        # 外置组件目录
-        self._external_components_dir = external_components_dir
-        # 初始化时一次性加载所有组件
-        self._load_all_components()
+        if os.path.exists(builtin_components_dir):
+            cls._load_components_from_dir(builtin_components_dir, overwrite=False)
     
-    def _load_all_components(self):
-        """一次性加载所有组件到缓存中"""
-        self._load_builtin_components()
-        self._load_external_components()
+    @classmethod
+    def _load_external_components(cls, external_components_dir=None):
+        """加载外置组件目录中的所有组件"""      
+        if external_components_dir and os.path.exists(external_components_dir):
+            cls._load_components_from_dir(external_components_dir, overwrite=True)
     
-    def _load_builtin_components(self):
-        """加载内置组件目录中的所有组件"""
-        if os.path.exists(self._builtin_components_dir):
-            self._load_components_from_dir(self._builtin_components_dir, overwrite=False)
-    
-    def _load_external_components(self):
-        """加载外置组件目录中的所有组件"""
-        if self._external_components_dir and os.path.exists(self._external_components_dir):
-            self._load_components_from_dir(self._external_components_dir, overwrite=True)
-    
-    def _load_components_from_dir(self, components_dir, overwrite=True):
+    @classmethod
+    def _load_components_from_dir(cls, components_dir, overwrite=True):
         """从指定目录加载组件
         
         Args:
@@ -60,73 +58,78 @@ class ComponentMixin:
             if filename.endswith('.xml'):
                 component_name = filename[:-4]  # 移除.xml扩展名
                 # 如果设置了不覆盖且组件已存在，则跳过
-                if not overwrite and component_name in self._component_cache:
+                if not overwrite and component_name in cls._component_cache:
                     continue
                     
                 filepath = os.path.join(components_dir, filename)
                 try:
                     with open(filepath, 'r', encoding='utf-8') as f:
                         template = f.read()
-                        self._component_cache[component_name] = template
+                        cls._component_cache[component_name] = template
                 except (FileNotFoundError, IOError):
                     pass
     
-    def process_components(self, xml: str) -> str:
+    @classmethod
+    def process_components(cls, xml: str) -> str:
         """编译XML，处理组件标签（支持自闭合和开始/结束标签）"""
         # 先处理开始/结束标签（slot功能）
-        xml = self._process_slots(xml)
+        xml = cls._process_slots(xml)
         # 再处理自闭合标签
-        xml = self._process_components(xml)
+        xml = cls._process_components(xml)
         return xml
     
-    def _process_slots(self, xml: str) -> str:
+    @classmethod
+    def _process_slots(cls, xml: str) -> str:
         """处理所有开始/结束标签，支持递归处理嵌套slot"""
         def process_slot(match):
             component_name, attrs_str, content = match.groups()
             # 提取属性
-            attrs = self._parse_attrs(attrs_str)
+            attrs = cls._parse_attrs(attrs_str)
             # 获取组件模板
-            component_template = self._get_component_template(component_name)
+            component_template = cls._get_component_template(component_name)
             if component_template:
                 # 递归处理内容中的嵌套slot
-                processed_content = self._process_slots(content)
+                processed_content = cls._process_slots(content)
                 # 渲染组件
-                return self._render_slot(component_template, processed_content, attrs)
+                return cls._render_slot(component_template, processed_content, attrs)
             else:
                 # 如果找不到组件，递归处理内容后返回原始标签
-                processed_content = self._process_slots(content)
+                processed_content = cls._process_slots(content)
                 return f'<{component_name}{attrs_str}>{processed_content}</{component_name}>'
         
         # 持续处理直到没有更多的slot标签
         prev_xml = None
         while prev_xml != xml:
             prev_xml = xml
-            xml = re.sub(self.SLOT_PATTERN, process_slot, xml, flags=re.VERBOSE | re.DOTALL)
+            xml = re.sub(cls.SLOT_PATTERN, process_slot, xml, flags=re.VERBOSE | re.DOTALL)
         
         return xml
     
-    def _process_components(self, xml: str) -> str:
+    @classmethod
+    def _process_components(cls, xml: str) -> str:
         """处理所有自闭合组件标签"""
         def process_component(match):
             component_name, attrs_str = match.groups()
             # 提取属性
-            attrs = self._parse_attrs(attrs_str)
+            attrs = cls._parse_attrs(attrs_str)
             # 获取组件模板
-            component_template = self._get_component_template(component_name)
+            component_template = cls._get_component_template(component_name)
             if component_template:
                 # 渲染组件
-                return self._render_component(component_template, attrs)
+                return cls._render_component(component_template, attrs)
             else:
                 # 如果找不到组件，返回原始标签
                 return match.group(0)
         
-        return re.sub(self.COMPONENT_PATTERN, process_component, xml, flags=re.VERBOSE)
+        return re.sub(cls.COMPONENT_PATTERN, process_component, xml, flags=re.VERBOSE)
     
-    def _get_component_template(self, component_name: str) -> str:
+    @classmethod
+    def _get_component_template(cls, component_name: str) -> str:
         """获取组件模板内容，从已加载的缓存中查找"""
-        return self._component_cache.get(component_name, '')
+        return cls._component_cache.get(component_name, '')
     
-    def _parse_attrs(self, attrs_str: str) -> dict:
+    @classmethod
+    def _parse_attrs(cls, attrs_str: str) -> dict:
         """解析属性字符串为字典"""
         attrs = {}
         if not attrs_str.strip():
@@ -140,7 +143,8 @@ class ComponentMixin:
         
         return attrs
     
-    def _render_slot(self, template: str, content: str, attrs: dict) -> str:
+    @classmethod
+    def _render_slot(cls, template: str, content: str, attrs: dict) -> str:
         """渲染slot模板，替换slot标签和变量"""
         result = template
         
@@ -173,7 +177,8 @@ class ComponentMixin:
         
         return result
     
-    def _render_component(self, template: str, attrs: dict) -> str:
+    @classmethod
+    def _render_component(cls, template: str, attrs: dict) -> str:
         """渲染组件模板，替换变量"""
         result = template
         
