@@ -15,13 +15,13 @@ def test_component_slot():
             f.write('<xl-p style="{{ style }}">{{ content }},<slot/></xl-p>')
         
         # 创建ComponentMixin实例，使用临时目录作为外置组件目录
-        processor = ComponentMixin(external_components_dir=temp_dir)
+        ComponentMixin._load_all_components(temp_dir)
         
         # 测试XML模板
         test_xml = '<xl-haha style="align:center" content="haha">123</xl-haha>'
         
         # 只使用ComponentMixin编译
-        compiled = processor.process_components(test_xml)
+        compiled = ComponentMixin.process_components(test_xml)
         
         # 验证结果
         expected = '<xl-p style="align:center">haha,123</xl-p>'
@@ -42,10 +42,10 @@ def test_slot_without_attributes():
             f.write('<xl-p style="{{ style }}">{{ content }},<slot/></xl-p>')
         
         # 创建ComponentMixin实例，使用临时目录作为外置组件目录
-        processor = ComponentMixin(external_components_dir=temp_dir)
+        ComponentMixin._load_all_components(temp_dir)
         
         test_xml = '<xl-haha>test content</xl-haha>'
-        compiled = processor.process_components(test_xml)
+        compiled = ComponentMixin.process_components(test_xml)
         
         # 由于找到了xl-haha组件模板，会进行替换，但没有提供content属性，{{content}}被替换为空字符串
         expected = '<xl-p>,test content</xl-p>'
@@ -66,10 +66,10 @@ def test_slot_with_style_only():
             f.write('<xl-p style="{{ style }}">{{ content }},<slot/></xl-p>')
         
         # 创建ComponentMixin实例，使用临时目录作为外置组件目录
-        processor = ComponentMixin(external_components_dir=temp_dir)
+        ComponentMixin._load_all_components(temp_dir)
         
         test_xml = '<xl-haha style="color:red">test content</xl-haha>'
-        compiled = processor.process_components(test_xml)
+        compiled = ComponentMixin.process_components(test_xml)
         
         # 由于找到了xl-haha组件模板，会进行替换，但没有提供content属性
         expected = '<xl-p style="color:red">,test content</xl-p>'
@@ -90,10 +90,10 @@ def test_slot_nested_content():
             f.write('<xl-p style="{{ style }}">{{ content }},<slot/></xl-p>')
         
         # 创建ComponentMixin实例，使用临时目录作为外置组件目录
-        processor = ComponentMixin(external_components_dir=temp_dir)
+        ComponentMixin._load_all_components(temp_dir)
         
         test_xml = '<xl-haha style="align:center" content="haha"><span>nested</span> content</xl-haha>'
-        compiled = processor.process_components(test_xml)
+        compiled = ComponentMixin.process_components(test_xml)
         
         # 验证结果
         expected = '<xl-p style="align:center">haha,<span>nested</span> content</xl-p>'
