@@ -15,8 +15,6 @@ class TestParagraphBasicProcessor:
 
         xml = '<xl-p style="align:left">检测结果及说明：</xl-p>'
         result = ParagraphProcessor.compile(xml)
-        print('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
-        print(result)
     
     def test_compile_paragraph_no_style(self):
         """测试编译无样式的段落"""
